%global githash aed66b1
%global gitdate 20211228

Name:           onednn
Version:        2.5.1
Release:        %{gitdate}.git%{githash}%{?dist}
Summary:        Deep Neural Network Library
License:        Apache
URL:            https://github.com/intel/onednn

Source0:        %{name}.tar.xz

Patch0:         mkl-dnn-gcc11.patch

BuildRequires:  cmake gcc-c++ doxygen
BuildRequires:  openblas-devel ocl-icd-devel
#BuildRequires:  tbb-devel


%global is_native 0
%global __cmake_in_source_build 1

%bcond_with native
%if %{with native}
%global is_native 1
%endif

%description
Deep Neural Network Library

%package devel
Summary: Development files
Requires: %{name} = %{version}-%{release}

%description devel
This package contains development files


%prep
%setup -q -n %{name}
# % patch0 -p0

%build

# openmp version of openblas
sed -i 's|"openblas"|"openblaso"|g' cmake/FindBLAS.cmake

# ommit TBB OCL cmake files from install
sed -i '/TBB/,/^endif/d' src/CMakeLists.txt
sed -i '/OCL/,/^endif/d' src/CMakeLists.txt

# relay on builtins
sed -i '/immintrin.h/d' src/gpu/jit/ngen/ngen_utils.hpp

mkdir build
pushd build
%cmake .. -Wno-dev \
       -DCMAKE_SKIP_RPATH=ON \
       -DCMAKE_VERBOSE_MAKEFILE=OFF \
       -DCMAKE_BUILD_TYPE=RelWithDebug \
       -DBUILD_SHARED_LIBS=ON \
       -DDNNL_BUILD_TESTS=OFF \
       -DDNNL_BLAS_VENDOR=OPENBLAS \
       -DDNNL_GPU_RUNTIME=OCL \
%ifarch ppc64le
       -DDNNL_GPU_RUNTIME=NONE \
%endif
       -DDNNL_CPU_RUNTIME=OMP \
       -DBLAS_INCLUDE_DIR=%{_includedir}/openblas \
%if %{is_native}
       -DDNNL_ARCH_OPT_FLAGS="-O3 -march=native"
%else
       -DDNNL_ARCH_OPT_FLAGS="-O3"
%endif
make %{?_smp_mflags}
popd


%install
rm -rf %{buildroot}

pushd build
make install DESTDIR=%{buildroot}
popd

rm -rf %{buildroot}/usr/share/doc/dnnl/README
rm -rf %{buildroot}/usr/share/doc/dnnl/LICENSE
rm -rf %{buildroot}/usr/share/doc/dnnl/THIRD-PARTY-PROGRAMS
rm -rf %{buildroot}/usr/share/doc/dnnl/reference/html/assets/mathjax/config/dnnl.js

mkdir -p %{buildroot}%{_includedir}/dnnl/common
mkdir -p %{buildroot}%{_includedir}/dnnl/cpu/jit_utils
mkdir -p %{buildroot}%{_includedir}/dnnl/cpu/x64/xbyak
mkdir -p %{buildroot}%{_includedir}/dnnl/cpu/jit_utils
install -p -m 0644 src/common/*.hpp %{buildroot}%{_includedir}/dnnl/common/
install -p -m 0644 src/cpu/x64/*.hpp %{buildroot}%{_includedir}/dnnl/cpu/x64/
install -p -m 0644 src/cpu/x64/xbyak/*.h %{buildroot}%{_includedir}/dnnl/cpu/x64/xbyak/
install -p -m 0644 src/cpu/jit_utils/*.hpp %{buildroot}%{_includedir}/dnnl/cpu/jit_utils/


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%doc examples doc
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/cmake/*
%{_libdir}/*.so


%changelog
* Sat Dec 14 2019 Balint Cristian <cristian.balint@gmail.com>
- first release
